@@ -27,6 +27,7 @@ import sys
 import os
 from datetime import datetime
 from time import sleep
+from optparse import OptionParser
 
 from PyQt4 import QtCore, QtGui
 try:
@@ -34,17 +35,22 @@ try:
 except:
     pass
 
-from lib.lib import *
-from lib.server import *
-from lib.sms_listener import *
-from lib.friend import *
-from lib.scheduler import *
+from lib.lib import banner_notification, list_presence_users
+from lib.server import Bonjour_server
+from lib.sms_listener import Sms_listener
+from lib.scheduler import Scheduler
+from lib.lib import logger
+from lib.friend import Friend
+from lib.config import config, Config_dialog
+from lib.friend_list import Friend_list_widget
 
 
 class MenuBar(QtGui.QMenuBar):
     def __init__(self, parent=None, ):
         QtGui.QMenuBar.__init__(self, parent)
         self.setObjectName("Menu")
+        self.preference = self.addAction(self.tr("&Preferences"))
+        self.about = self.addAction(self.tr("&About"))
         ## Quit
         self.quit = self.addAction(self.tr("&Quit"))
 
@@ -57,21 +63,24 @@ class Central_widget(QtGui.QWidget):
         # Load gui items
         self.bonjour_users_label = QtGui.QLabel('Select your Bonjour '
                                                 'contact id :')
-        self.empty = QtGui.QLabel('')
         self.bonjour_users_label.setFixedHeight(50)
         self.bonjour_users = QtGui.QComboBox()
-        self.start_server_button = QtGui.QPushButton('Start server')
         icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
                            '/general_refresh.png')
         self.reload_bonjour_users_button = QtGui.QPushButton()
         self.reload_bonjour_users_button.setIcon(icon)
         self.reload_bonjour_users_button.setFixedWidth(80)
+        self.empty = QtGui.QLabel('')
+        self.friend_list_label = QtGui.QLabel('Friends list :')
+        self.friends_list = Friend_list_widget(self)
         mainLayout = QtGui.QGridLayout()
-        mainLayout.addWidget(self.bonjour_users_label, 0, 0, 2, 1)
+        mainLayout.addWidget(self.bonjour_users_label, 0, 0, 1, 2)
         mainLayout.addWidget(self.bonjour_users, 1, 0)
         mainLayout.addWidget(self.reload_bonjour_users_button, 1, 1)
-        mainLayout.addWidget(self.empty, 2, 0, 2, 1)
-#        mainLayout.addWidget(self.start_server_button, 2, 0)
+        
+        mainLayout.addWidget(self.empty, 4, 0, 1, 2)
+        mainLayout.addWidget(self.friend_list_label, 5, 0, 1, 2)
+        mainLayout.addWidget(self.friends_list, 6, 0, 1, 2)
 
         mainLayout.setRowStretch(0, 0)
         self.setLayout(mainLayout)
@@ -87,10 +96,26 @@ class Central_widget(QtGui.QWidget):
         if len(self.parent.bonjour_users) == 0:
             banner_notification("No Bonjour contacts found !")
         else:
+            node_friend_list = [f.node for f in 
+                                self.parent.scheduler.friend_list]
             for bonjour_user, info in self.parent.bonjour_users.items():
+                # if the contact was create by heysms
+                # we don't want to see it in the list
+                if bonjour_user in node_friend_list:
+                        continue
                 self.bonjour_users.addItem(bonjour_user)
-            self.parent.bonjour_auth_user = self.bonjour_users.currentText()
+            # Read last bonjour_contact used
+            last_authorized_bonjour_contact = config.read_last_authorized_bonjour_contact()
+            # Search in list last bonjour_contact used
+            index = self.bonjour_users.findText(last_authorized_bonjour_contact)
+            if index != -1:
+                # Select last bonjour_contact used
+                logger.debug("Last Bonjour contact found: %s, we select it" % last_authorized_bonjour_contact)
+                self.bonjour_users.setCurrentIndex(index)
+
+            self.parent.change_bonjour_user(self.bonjour_users.currentText())
             banner_notification("Bonjour contacts loaded !")
+
         self.parent.main_window.setAttribute(
                                     QtCore.Qt.WA_Maemo5ShowProgressIndicator,
                                     False)
@@ -103,15 +128,20 @@ class Ui_MainWindow(QtCore.QObject):
         self.friend_list = []
         self.bonjour_auth_user = ''
         self.bonjour_users = {}
-        #self.config = config.Config(parent=self)
 
     def setupUi(self, main_window):
         self.main_window = main_window
         self.main_window.setObjectName("MainWindow")
         self.main_window.resize(800, 400)
+        icon = QtGui.QIcon('/usr/share/icons/hicolor/128x128/apps'
+                           '/heysms.png')
+        self.main_window.setWindowIcon(icon)
 
         self.central_widget = Central_widget(self)
         self.main_window.setCentralWidget(self.central_widget)
+        self.main_window.conf_dialog = Config_dialog(self.main_window)
+        # Set ui
+        config.init_profile()
 
         ### Menu
         self.menubar = MenuBar(self.main_window)
@@ -123,13 +153,18 @@ class Ui_MainWindow(QtCore.QObject):
         QtCore.QObject.connect(self.central_widget.reload_bonjour_users_button,
                                QtCore.SIGNAL("pressed ()"),
                                self.central_widget.reload_contacts)
-        QtCore.QObject.connect(self.central_widget.start_server_button,
-                               QtCore.SIGNAL("pressed ()"),
-                               self.toggle_server)
         QtCore.QObject.connect(self.central_widget.bonjour_users,
                                QtCore.SIGNAL("currentIndexChanged "
                                              "(const QString&)"),
                                self.change_bonjour_user)
+
+        QtCore.QObject.connect(self.menubar.preference,
+                               QtCore.SIGNAL("triggered()"),
+                               self.main_window.conf_dialog.exec_)
+
+        QtCore.QObject.connect(self.menubar.about,
+                               QtCore.SIGNAL("triggered()"),
+                               self.show_about)
         ## Quit
         QtCore.QObject.connect(self.menubar.quit,
                                QtCore.SIGNAL("triggered()"),
@@ -141,10 +176,9 @@ class Ui_MainWindow(QtCore.QObject):
                                          .currentText()
             self.bs = Bonjour_server(self.bonjour_auth_user)
         if self.bs.is_running():
-            self.bs.stop()
-            self.central_widget.start_server_button.setText("Start Server")
+            pass
+#            self.bs.stop()
         else:
-            self.central_widget.start_server_button.setText("Stop Server")
             self.bs.listen()
 
     def change_bonjour_user(self, new_bonjour_user):
@@ -154,33 +188,73 @@ class Ui_MainWindow(QtCore.QObject):
             self.bs.set_auth(new_bonjour_user)
             self.bonjour_auth_user = new_bonjour_user
             self.scheduler.set_auth(new_bonjour_user)
+            config.update_last_authorized_user(new_bonjour_user)
+
+    def show_about(self):
+        icon = QtGui.QIcon('/usr/share/icons/hicolor/48x48/hildon'
+                           '/general_refresh.png')
+        vars = {}
+        vars['version'] = "1.3.0"
+        message = QtCore.QString("""<center><h2>HeySms</h2></center>"""
+                                 """<center>Version: %(version)s</center>"""
+                                 """<br/>Visite web site: <a href="http://talk.maemo.org/showthread.php?t=84705">Here</a> """
+                                 """<br/>Report bugs: <a href="https://github.com/titilambert/HeySms/issues?milestone=&page=1&state=open">Here</a> """
+                                 """<br/>Thanks: """
+                                 """<ul>"""
+                                 """<li>My Doudoune</li>"""
+                                 """<li>David Rodigari</li>"""
+                                 """<li>Oskar Welzl</li>"""
+                                 """</ul>"""
+                                 """ """ % vars)
+        QtGui.QMessageBox.about(self.main_window, "About", message)
 
 
 def main():
+
+    def exit():
+        logger.debug("Stopping active friends")
+        for f in ui.friend_list:
+            f.close()
+        logger.debug("Restore profile")
+        config.restore_profile()
+
+    opt_parser = OptionParser()
+    opt_parser.add_option("-d", "--debug", dest="debug_mode",
+                          action="store_true",
+                          default='False', help="Debug mode")
+
     app = QtGui.QApplication(sys.argv)
 #    app.setOrganizationName("HeySms")
 #    app.setOrganizationDomain("HeySms")
     app.setApplicationName("HeySms")
+    (options, args) = opt_parser.parse_args([str(i) for i in app.arguments()])
+    logger.set_debug(options.debug_mode)
+    
     main_window = QtGui.QMainWindow()
     ui = Ui_MainWindow(app)
     ui.setupUi(main_window)
+    config.parent = ui
 
     ui.sms_listener = Sms_listener(ui)
     ui.sms_listener.start()
+    logger.debug("Sms_listener started")
     ui.scheduler = Scheduler(ui)
     ui.scheduler.start()
+    logger.debug("Scheduler started")
 
     main_window.setWindowTitle("HeySms")
     main_window.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
-#    main_window.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow, True)
-# QtCore.Qt.WA_Maemo5NonComposited
-# QtCore.Qt.WA_Maemo5ShowProgressIndicator
-# QtCore.Qt.WA_Maemo5LandscapeOrientation
-# QtCore.Qt.WA_Maemo5PortraitOrientation
-# QtCore.Qt.WA_Maemo5StackedWindow
     main_window.show()
     main_window.repaint()
     ui.central_widget.repaint()
     ui.central_widget.reload_contacts()
 
+
+    QtCore.QObject.connect(app,
+                           QtCore.SIGNAL("lastWindowClosed()"),
+                           exit)
+
     sys.exit(app.exec_())
+
+
+    
